==> ibiz-model-util-8.1.0.372-sources.jar: net/ibizsys/model/util/transpiler/extend/control/form/PSDEFormItemUpdateListTranspilerEx.java <==
package net.ibizsys.model.util.transpiler.extend.control.form;

import net.ibizsys.model.IPSModelObject;
import net.ibizsys.model.control.form.IPSDEFIUpdateDetail;
import net.ibizsys.model.control.form.IPSDEFormItemUpdate;
import net.ibizsys.model.util.transpiler.IPSModelTranspileContext;
import net.ibizsys.psmodel.core.domain.PSDEFIUDetail;
import net.ibizsys.psmodel.core.domain.PSDEFIUpdate;
import net.ibizsys.psmodel.core.util.IPSModel;

public class PSDEFormItemUpdateListTranspilerEx extends net.ibizsys.model.util.transpiler.control.form.PSDEFormItemUpdateListTranspiler{
	@Override
	protected void onDecompile(IPSModelTranspileContext iPSModelTranspileContext, IPSModelObject iPSModelObject, IPSModel domain, boolean bFullMode) throws Exception {
		super.onDecompile(iPSModelTranspileContext, iPSModelObject, domain, bFullMode);
		
		if(bFullMode) {
			IPSDEFormItemUpdate iPSDEFormItemUpdate = (IPSDEFormItemUpdate)iPSModelObject;
			PSDEFIUpdate psDEFIUpdate = (PSDEFIUpdate)domain;
			
			if(iPSDEFormItemUpdate.getPSDEFIUpdateDetails()!=null) {
				int nOrder = 100;
				iPSModelTranspileContext.getPSModelListTranspiler(IPSDEFIUpdateDetail.class, false).decompile(iPSModelTranspileContext, iPSDEFormItemUpdate.getPSDEFIUpdateDetails(), psDEFIUpdate.getPSDEFIDetailsIf(), bFullMode);
				for(PSDEFIUDetail child : psDEFIUpdate.getPSDEFIDetailsIf()) {
					child.setPSDEFIUpdateId(psDEFIUpdate.getId());
					child.setPSDEFIUpdateName(psDEFIUpdate.getName());
					//child.setOrderValue(nOrder);
					nOrder += 100;
				}
			}
		}
	}
}

==> ibiz-model-util-8.1.0.458-sources.jar: net/ibizsys/model/util/transpiler/extend/control/form/PSDEFormItemUpdateListTranspilerEx.java <==
package net.ibizsys.model.util.transpiler.extend.control.form;

import org.springframework.util.ObjectUtils;

import com.fasterxml.jackson.databind.node.ArrayNode;
import com.fasterxml.jackson.databind.node.ObjectNode;

import net.ibizsys.model.IPSModelObject;
import net.ibizsys.model.control.form.IPSDEFIUpdateDetail;
import net.ibizsys.model.control.form.IPSDEFormItemUpdate;
import net.ibizsys.model.control.form.PSDEFormImpl;
import net.ibizsys.model.util.transpiler.IPSModelTranspileContext;
import net.ibizsys.psmodel.core.domain.PSDEFIUDetail;
import net.ibizsys.psmodel.core.domain.PSDEFIUpdate;
import net.ibizsys.psmodel.core.util.IPSModel;

public class PSDEFormItemUpdateListTranspilerEx extends net.ibizsys.model.util.transpiler.control.form.PSDEFormItemUpdateListTranspiler{
	@Override
	protected void onDecompile(IPSModelTranspileContext iPSModelTranspileContext, IPSModelObject iPSModelObject, IPSModel domain, boolean bFullMode) throws Exception {
		super.onDecompile(iPSModelTranspileContext, iPSModelObject, domain, bFullMode);
		
		if(bFullMode) {
			IPSDEFormItemUpdate iPSDEFormItemUpdate = (IPSDEFormItemUpdate)iPSModelObject;
			PSDEFIUpdate psDEFIUpdate = (PSDEFIUpdate)domain;
			
			if(iPSDEFormItemUpdate.getPSDEFIUpdateDetails()!=null) {
				int nOrder = 100;
				iPSModelTranspileContext.getPSModelListTranspiler(IPSDEFIUpdateDetail.class, false).decompile(iPSModelTranspileContext, iPSDEFormItemUpdate.getPSDEFIUpdateDetails(), psDEFIUpdate.getPSDEFIDetailsIf(), bFullMode);
				for(PSDEFIUDetail child : psDEFIUpdate.getPSDEFIDetailsIf()) {
					child.setPSDEFIUpdateId(psDEFIUpdate.getId());
					child.setPSDEFIUpdateName(psDEFIUpdate.getName());
					//child.setOrderValue(nOrder);
					nOrder += 100;
				}
			}
		}
	}
	
	@Override
	protected void onCompile(IPSModelTranspileContext iPSModelTranspileContext, IPSModel domain, ObjectNode objectNode) throws Exception {
		super.onCompile(iPSModelTranspileContext, domain, objectNode);
		
		PSDEFIUpdate psDEFIUpdate = (PSDEFIUpdate)domain;
		
		if(!ObjectUtils.isEmpty(psDEFIUpdate.getPSDEFIDetails())) {
			ArrayNode arrayNode = objectNode.putArray(PSDEFormImpl.ATTR_GETPSDEFORMITEMUPDATES);
			iPSModelTranspileContext.getPSModelListTranspiler(IPSDEFIUpdateDetail.class, false).compile(iPSModelTranspileContext, psDEFIUpdate.getPSDEFIDetails(), arrayNode);
		}
		
	}
}
